@@ -7,12 +7,12 @@ EV::ADNS - lightweight asynchronous dns queries using EV and libadns
  use EV;
  use EV::ADNS;
 
- EV::ADNS::submit "example.com", EV::ADNS::r_addr, 0, sub {
+ EV::ADNS::submit "example.com", EV::ADNS::r_addr, EV::ADNS::qf_cname_loose, sub {
     my ($status, $expires, @a) = @_;
     warn $a[0]; # "127.13.166.3" etc.
  };
 
- EV::loop;
+ EV::run;
 
 =head1 DESCRIPTION
 
@@ -28,9 +28,8 @@ not do anything (except run an EV event loop).
 =head1 OVERVIEW
 
 All the constants/enums from F<adns.h> are available in the EV::ADNS
-namespace, without the C<adns_> prefix, e.g. C<adns_r_a> becomes
-C<EV::ADNS::r_a>, C<adns__qtf_deref> becomes C<EV::ADNS::_qtf_deref> and
-so on.
+namespace, without the C<adns_> prefix, i.e. C<adns_r_a> becomes
+C<EV::ADNS::r_a> and so on.
 
 =head1 FUNCTIONS
 
@@ -41,7 +40,7 @@ so on.
 Submits a new request to be handled. See the C<adns_submit> C function
 description for more details. The function optionally returns a query
 object which can be used to cancel an in-progress request. You do not need
-to store the query object, even if you ignore it the query will proceed.
+to store the query object, even if you ignore it, the query will proceed.
 
 The callback will be invoked with a result status, the time the resource
 record validity expires and zero or more resource records, one scalar per
@@ -77,9 +76,8 @@ An arrayref of strings.
 
 A "host address", a hostname with any number of addresses (hint records).
 
-Currently only the hostname will be stored, so this is alway an arrayref
-with a single element of the hostname. Future versions might add
-additional address entries.
+The record will be an arrayref with domainname, adns status and any number
+of associated addresses: C<< ["domain", adns_status, addr...] >>.
 
 =item EV::ADNS::r_hinfo
 
@@ -94,7 +92,7 @@ An arrayref with two strings.
 An arrayref consisting of the priority and a "host address" (see
 C<EV::ADNS::r_ns>). Example:
 
-   [10, "mail10.example.com"]
+   [10, [["alt3.aspmx.l.google.com", 0, "64.233.189.27", "2404:6800:4008:c07::1a"]]]
 
 =item EV::ADNS::r_mx_raw
 
@@ -135,6 +133,20 @@ Currently C<undef>.
 
 Cancels a request that is in progress.
 
+=item EV::ADNS::reinit undef, $resolvdata_or_undef
+
+Cancels all outstanding queries, frees all adns state and reinitialises
+it. It is highly recommended to only call this when there are no
+outstanding requests.
+
+The first argument must currently be specified as C<undef>.
+
+The second argument can be missing or C<undef>; in which case the normal
+initialisation is done (such as reading the F<resolv.conf>), or it might
+be a stirng, in which case no config files or environment variables will
+be read and the given string will be interpreted as the F<resolv.conf>
+contents.
+
 =back
 
 =cut
@@ -145,7 +157,7 @@ use Carp ();
 use EV ();
 
 BEGIN {
-   $VERSION = 2.3;
+   $VERSION = '3.0';
 
    require XSLoader;
    XSLoader::load (EV::ADNS, $VERSION);
